__all__ = (
    'GLOBAL_DOMAIN_ARG',
    'MAX_CONCURRENT_EXPORT_TASKS',
)

GLOBAL_DOMAIN_ARG = '-globalDomain'
MAX_CONCURRENT_EXPORT_TASKS = 40
